#ifndef _FlyCAMm1_H_
#define _FlyCAMm1_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <cardserv.h>

// =================================================================
//
// Backward compatible IOControlCode values
//
#define CAM_IOCTL_SETINFO					0x01  // set camera info
#define CAM_IOCTL_GETINFO					0x02  // get camera info
#define CAM_IOCTL_GETDATA					0x03  // get a frame data from camera
#define CAM_IOCTL_GETVER					0x04  // get driver version
#define CAM_IOCTL_GETPOWER					0x05  // get power value
#define CAM_IOCTL_SETBRIGHTNESS				0x11
#define CAM_IOCTL_GETBRIGHTNESS				0x12
#define CAM_IOCTL_SETCONTRAST				0x13
#define CAM_IOCTL_GETCONTRAST				0x14
#define CAM_IOCTL_SETSATURATION				0x15
#define CAM_IOCTL_GETSATURATION				0x16
#define CAM_IOCTL_SETHUE					0x17
#define CAM_IOCTL_GETHUE					0x18
#define CAM_IOCTL_SETColorRWeight			0x19
#define CAM_IOCTL_SETColorGWeight			0x1A
#define CAM_IOCTL_SETColorBWeight			0x1B
#define CAM_IOCTL_GETColorRWeight			0x1C
#define CAM_IOCTL_GETColorGWeight			0x1D
#define CAM_IOCTL_GETColorBWeight			0x1E
#define CAM_IOCTL_SetSensorMode				0x1F
#define CAM_IOCTL_GETPLDVER					0x20
#define CAM_IOCTL_SetFlickerCancel			0x21
#define CAM_IOCTL_SetPreview				0x22
#define CAM_IOCTL_SetCapture				0x23
#define CAM_IOCTL_SetSnapshotFlag			0x24
#define CAM_IOCTL_GetSnapshotFlag			0x25
#define CAM_IOCTL_SetClockRate				0x26
#define CAM_IOCTL_INIT_CAMERA				0x27
#define CAM_IOCTL_DEINIT_CAMERA				0x28
#define CAM_IOCTL_OVIC_REG_SET				0x29
#define CAM_IOCTL_OVIC_REG_GET				0x2A
#define CAM_IOCTL_GETExposureHigh			0x2B
#define CAM_IOCTL_SETExposureHigh			0x2C
#define CAM_IOCTL_GETExposureLow			0x2D
#define CAM_IOCTL_SETExposureLow			0x2E
#define CAM_IOCTL_SETImageVideoMode			0x2F
#define CAM_IOCTL_SETSharpen				0x30
#define CAM_IOCTL_GETSharpen				0x31
#define CAM_IOCTL_SETLuminosity				0x32
#define CAM_IOCTL_SETEnvironmentMode		0x33
#define CAM_IOCTL_GETEnvironmentDef			0x34
#define CAM_IOCTL_OVIC_REG_SET1				0x35
#define CAM_IOCTL_OVIC_REG_SET2				0x36
#define CAM_IOCTL_SETFlashEnable			0x37
#define CAM_IOCTL_SETFlashTakePhotoDistance	0x38
#define CAM_IOCTL_GETFlashState				0x39
#define CAM_IOCTL_CHECK_FLYCAMM1			0x3A
#define CAM_IOCTL_MoonlightMode			    0x4A

// New IOControlCode values

#define IOCTL_CAM_BASE FILE_DEVICE_STREAMS

#define IOCTL_CAM_SETINFO         \
    CTL_CODE(IOCTL_CAM_BASE, 0x800, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_CAM_GETINFO         \
    CTL_CODE(IOCTL_CAM_BASE, 0x801, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define IOCTL_CAM_GETDATA         \
    CTL_CODE(IOCTL_CAM_BASE, 0x802, METHOD_BUFFERED, FILE_ANY_ACCESS)

#define YUVMode 0x00
#define RGBMode 0x01
// =================================================================
//
// Structure to keep track of a CAM
//
typedef struct _CAM_INFO
{
	DWORD	width;		// Width (0 - 720)
	DWORD	height;		// Height (0 - 480)
	DWORD	system;		// 1:NTSC, 2:PAL
	DWORD	format;		// 1:YUV, 2:RGB
	DWORD	bpp;		// Bpp
	DWORD	rotate;		// 0:upright, 1:invert
	DWORD	flags;		// ignore
} CAM_INFO, * PCAM_INFO;

typedef struct _CAM {
    struct _CAM * c_next;
	HANDLE	c_hThread;
    CARD_CLIENT_HANDLE c_hPcmcia;   // PCMCIA client driver handle
    CARD_SOCKET_HANDLE c_hSock;     // socket the CAM card is in.

    CARD_WINDOW_HANDLE c_hATAReg;   // Handle to ATA I/O register window
    volatile PUCHAR c_pATAReg;
    CARD_WINDOW_HANDLE c_hATARegAlt;// Handle to ATA alternate reg window
    volatile PUCHAR c_pATARegAlt;

    CRITICAL_SECTION c_CameraCardCrit;// guard access to global state and card
    DWORD c_CameraCardState;
    UCHAR c_CameraStatus;      // CAM status register at interrupt time

    HANDLE c_IRQEvent;
	DWORD c_status;
    CAM_INFO c_Info;    // for CAM_IOCTL_GET/SETINFOs
 
    BOOL  c_f16Bit;
	PUSHORT c_AlignBuf;      // 16 bit aligned sector buffer
    LPTSTR c_ActivePath;     // Active key registry path
} CAM, * PCAM; 

typedef struct
{
	int		brightness;
	int		contrast;
	int		saturation;
	int		hue;
	int		luminosity;
	int		sharpenMode;
	int		getMode;
} EnvMo_INFO, * PEnvMo_INFO;
// =================================================================
//
// Global Variables
//

//
// Global functions
//

// =================================================================
#ifdef __cplusplus
}
#endif

#endif // _FlyCAM_H_

